#ifndef __STATUSBAR_H__
#define __STATUSBAR_H__

/**
 * File Name  : statusbar.h
 *
 * Description: The statusbar item functions
 */

/*
 * This file is part of popupmenu.
 *
 * popupmenu is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * popupmenu is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

#include <glib.h>

G_BEGIN_DECLS

//----------------------------------------------------------------------------
// Global Variables
//----------------------------------------------------------------------------

GtkWindow *g_statusbar_window;


//============================================================================
// Public Functions
//============================================================================

/**---------------------------------------------------------------------------
 *
 * Name :  statusbar_create
 *
 * @brief  Create and initialize the statusbar
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
typedef GtkWidget*(*dialog_cb_t)(GtkMessageType type,
                               const char *title, 
                               const char *message,
                               eripc_context_t *context,
                               const char *message_id);
void statusbar_create(dialog_cb_t cb);


/**---------------------------------------------------------------------------
 *
 * Name :  statusbar_item_set_state
 *
 * @brief  Set the state of a status bar item
 *
 * @param  item          Item name
 * @param  statename     Name of new state
 *
 * @return Returns TRUE on success, FALSE otherwise
 *
 *--------------------------------------------------------------------------*/
gboolean statusbar_item_set_state(const char *item, const char *statename);

/**---------------------------------------------------------------------------
 *
 * Name :  statusbar_item_show
 *
 * @brief  Show a status bar item
 *
 * @param  item     Item name
 * @param  mode     New mode (show/hide)  
*
 * @return Returns TRUE on success, FALSE otherwise
 *
 *--------------------------------------------------------------------------*/
gboolean statusbar_item_show(const char *item, const char *mode);

/**---------------------------------------------------------------------------
 *
 * Name :  statusbar_remove_item
 *
 * @brief  Remove and free a status bar item
 *
 * @param  item     Item name
 *
 * @return Returns TRUE on success, FALSE otherwise
 *
 *--------------------------------------------------------------------------*/
gboolean statusbar_remove_item(const char *item);

/**---------------------------------------------------------------------------
 *
 * Name :  statusbar_update_battery_state
 *
 * @brief  Update battery state icon
 *
 * @param  level    Battery level in percent
 * @param  state    Charge state string
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void statusbar_update_battery_state(gint level, const char *state);

void statusbar_update_signal_strength(const char *medium, gint strength);

void statusbar_update_pagecounter(gint curpage, gint numpages, gboolean boundary_check);

void statusbar_hide_pagecounter();

void statusbar_set_text(void);

#if MACHINE_IS_DR1000S || MACHINE_IS_DR1000SW
void statusbar_update_toolbar();
#endif

//------------------------- Functions for Last Opened documents/applications
void taskbar_store_tasks(int mode);

G_END_DECLS

#endif

